@@ -30,7 +30,7 @@ from gitlab.exceptions import *  # noqa
 from gitlab import utils  # noqa
 
 __title__ = "python-gitlab"
-__version__ = "2.0.1"
+__version__ = "2.1.1"
 __author__ = "Gauvain Pocentek"
 __email__ = "gauvainpocentek@gmail.com"
 __license__ = "LGPL3"
@@ -90,8 +90,8 @@ class Gitlab(object):
 
         self._api_version = str(api_version)
         self._server_version = self._server_revision = None
-        self._base_url = url
-        self._url = "%s/api/v%s" % (url, api_version)
+        self._base_url = url.rstrip("/")
+        self._url = "%s/api/v%s" % (self._base_url, api_version)
         #: Timeout to use for requests to gitlab server
         self.timeout = timeout
         #: Headers that will be used in request to GitLab
@@ -144,6 +144,7 @@ class Gitlab(object):
         self.features = objects.FeatureManager(self)
         self.pagesdomains = objects.PagesDomainManager(self)
         self.user_activities = objects.UserActivitiesManager(self)
+        self.applications = objects.ApplicationManager(self)
 
     def __enter__(self):
         return self
@@ -640,6 +641,12 @@ class Gitlab(object):
         get_all = kwargs.pop("all", False)
         url = self._build_url(path)
 
+        # use keyset pagination automatically, if all=True
+        order_by = kwargs.get("order_by")
+        if get_all and (not order_by or order_by == "id"):
+            kwargs["pagination"] = "keyset"
+            kwargs["order_by"] = "id"
+
         if get_all is True and as_list is True:
             return list(GitlabList(self, url, query_data, **kwargs))
 
